==> apache-iotdb-1.3.2-source-release.zip: apache-iotdb-1.3.2/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/pipe/agent/plugin/dataregion/PipeDataRegionPluginAgent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.pipe.agent.plugin.dataregion;

import org.apache.iotdb.commons.pipe.agent.plugin.PipeConnectorConstructor;
import org.apache.iotdb.commons.pipe.agent.plugin.PipeExtractorConstructor;
import org.apache.iotdb.commons.pipe.agent.plugin.PipePluginAgent;
import org.apache.iotdb.commons.pipe.agent.plugin.PipeProcessorConstructor;
import org.apache.iotdb.commons.pipe.plugin.meta.DataNodePipePluginMetaKeeper;
import org.apache.iotdb.commons.pipe.plugin.meta.PipePluginMetaKeeper;

public class PipeDataRegionPluginAgent extends PipePluginAgent {

  public PipeDataRegionPluginAgent(DataNodePipePluginMetaKeeper pipePluginMetaKeeper) {
    super(pipePluginMetaKeeper);
  }

  @Override
  protected PipeExtractorConstructor createPipeExtractorConstructor(
      PipePluginMetaKeeper pipePluginMetaKeeper) {
    return new PipeDataRegionExtractorConstructor(
        (DataNodePipePluginMetaKeeper) pipePluginMetaKeeper);
  }

  @Override
  protected PipeProcessorConstructor createPipeProcessorConstructor(
      PipePluginMetaKeeper pipePluginMetaKeeper) {
    return new PipeDataRegionProcessorConstructor(
        (DataNodePipePluginMetaKeeper) pipePluginMetaKeeper);
  }

  @Override
  protected PipeConnectorConstructor createPipeConnectorConstructor(
      PipePluginMetaKeeper pipePluginMetaKeeper) {
    return new PipeDataRegionConnectorConstructor(
        (DataNodePipePluginMetaKeeper) pipePluginMetaKeeper);
  }
}

==> apache-iotdb-1.3.5-source-release.zip: apache-iotdb-1.3.5/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/pipe/agent/plugin/dataregion/PipeDataRegionPluginAgent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.pipe.agent.plugin.dataregion;

import org.apache.iotdb.commons.pipe.agent.plugin.PipePluginAgent;
import org.apache.iotdb.commons.pipe.agent.plugin.constructor.PipeConnectorConstructor;
import org.apache.iotdb.commons.pipe.agent.plugin.constructor.PipeExtractorConstructor;
import org.apache.iotdb.commons.pipe.agent.plugin.constructor.PipeProcessorConstructor;
import org.apache.iotdb.commons.pipe.agent.plugin.meta.DataNodePipePluginMetaKeeper;
import org.apache.iotdb.commons.pipe.agent.plugin.meta.PipePluginMetaKeeper;

public class PipeDataRegionPluginAgent extends PipePluginAgent {

  public PipeDataRegionPluginAgent(DataNodePipePluginMetaKeeper pipePluginMetaKeeper) {
    super(pipePluginMetaKeeper);
  }

  @Override
  protected PipeExtractorConstructor createPipeExtractorConstructor(
      PipePluginMetaKeeper pipePluginMetaKeeper) {
    return new PipeDataRegionExtractorConstructor(
        (DataNodePipePluginMetaKeeper) pipePluginMetaKeeper);
  }

  @Override
  protected PipeProcessorConstructor createPipeProcessorConstructor(
      PipePluginMetaKeeper pipePluginMetaKeeper) {
    return new PipeDataRegionProcessorConstructor(
        (DataNodePipePluginMetaKeeper) pipePluginMetaKeeper);
  }

  @Override
  protected PipeConnectorConstructor createPipeConnectorConstructor(
      PipePluginMetaKeeper pipePluginMetaKeeper) {
    return new PipeDataRegionConnectorConstructor(
        (DataNodePipePluginMetaKeeper) pipePluginMetaKeeper);
  }
}
